==> paraview-v3.0.1.zip: paraview-v3.0.1/Qt/Chart/pqHistogramModel.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqHistogramModel.cxx

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.1. 

   See License_v1.1.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

/// \file pqHistogramModel.cxx
/// \date 8/15/2006

#include "pqHistogramModel.h"


pqHistogramModel::pqHistogramModel(QObject *parentObject)
  : QObject(parentObject)
{
}

void pqHistogramModel::resetBinValues()
{
  emit this->binValuesReset();
}

void pqHistogramModel::beginInsertBinValues(int first, int last)
{
  emit this->aboutToInsertBinValues(first, last);
}

void pqHistogramModel::endInsertBinValues()
{
  emit this->binValuesInserted();
}

void pqHistogramModel::beginRemoveBinValues(int first, int last)
{
  emit this->aboutToRemoveBinValues(first, last);
}

void pqHistogramModel::endRemoveBinValues()
{
  emit this->binValuesRemoved();
}

==> paraview-v3.2.2.zip: paraview-v3.2.2/Qt/Chart/pqHistogramModel.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqHistogramModel.cxx

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.1. 

   See License_v1.1.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

/// \file pqHistogramModel.cxx
/// \date 8/15/2006

#include "pqHistogramModel.h"


pqHistogramModel::pqHistogramModel(QObject *parentObject)
  : QObject(parentObject)
{
}

void pqHistogramModel::beginInsertBins(int first, int last)
{
  emit this->aboutToInsertBins(first, last);
}

void pqHistogramModel::endInsertBins()
{
  emit this->binsInserted();
}

void pqHistogramModel::beginRemoveBins(int first, int last)
{
  emit this->aboutToRemoveBins(first, last);
}

void pqHistogramModel::endRemoveBins()
{
  emit this->binsRemoved();
}
